@@ -25,6 +25,11 @@
 
 
 TEST_IMPL(platform_output) {
+/* TODO(gengjiawen): Fix test on QEMU. */
+#if defined(__QEMU__)
+  RETURN_SKIP("Test does not currently work in QEMU");
+#endif
+
   char buffer[512];
   size_t rss;
   size_t size;
@@ -35,6 +40,7 @@ TEST_IMPL(platform_output) {
   uv_cpu_info_t* cpus;
   uv_interface_address_t* interfaces;
   uv_passwd_t pwd;
+  uv_utsname_t uname;
   int count;
   int i;
   int err;
@@ -57,9 +63,13 @@ TEST_IMPL(platform_output) {
 #endif
 
   err = uv_uptime(&uptime);
+#if defined(__PASE__)
+  ASSERT(err == UV_ENOSYS);
+#else
   ASSERT(err == 0);
   ASSERT(uptime > 0);
   printf("uv_uptime: %f\n", uptime);
+#endif
 
   err = uv_getrusage(&rusage);
   ASSERT(err == 0);
@@ -153,5 +163,13 @@ TEST_IMPL(platform_output) {
   ASSERT(ppid > 0);
   printf("uv_os_getppid: %d\n", (int) ppid);
 
+  err = uv_os_uname(&uname);
+  ASSERT(err == 0);
+  printf("uv_os_uname:\n");
+  printf("  sysname: %s\n", uname.sysname);
+  printf("  release: %s\n", uname.release);
+  printf("  version: %s\n", uname.version);
+  printf("  machine: %s\n", uname.machine);
+
   return 0;
 }
